==> avogadro-debuginfo-1.2.0-1.tar.xz: usr/src/debug/avogadro-1.2.0-1/libavogadro/src/qrc_pythontool.cxx <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/avogadro/avogadro-1.2.0-1.x86_64/src/avogadro-1.2.0/libavogadro/src/python.png
  0x0,0x0,0x4,0x54,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x20,0x0,0x0,0x0,0x20,0x8,0x6,0x0,0x0,0x0,0x73,0x7a,0x7a,0xf4,
  0x0,0x0,0x0,0x4,0x73,0x42,0x49,0x54,0x8,0x8,0x8,0x8,0x7c,0x8,0x64,0x88,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xa,0xf0,0x0,0x0,0xa,0xf0,
  0x1,0x42,0xac,0x34,0x98,0x0,0x0,0x0,0x25,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,
  0x74,0x77,0x61,0x72,0x65,0x0,0x4d,0x61,0x63,0x72,0x6f,0x6d,0x65,0x64,0x69,0x61,
  0x20,0x46,0x69,0x72,0x65,0x77,0x6f,0x72,0x6b,0x73,0x20,0x4d,0x58,0x20,0x32,0x30,
  0x30,0x34,0x87,0x76,0xac,0xcf,0x0,0x0,0x0,0x16,0x74,0x45,0x58,0x74,0x43,0x72,
  0x65,0x61,0x74,0x69,0x6f,0x6e,0x20,0x54,0x69,0x6d,0x65,0x0,0x30,0x36,0x2f,0x30,
  0x35,0x2f,0x30,0x34,0x4d,0xbe,0xe6,0x71,0x0,0x0,0x3,0xa3,0x49,0x44,0x41,0x54,
  0x78,0x9c,0xb5,0x56,0x4d,0x88,0x1c,0x55,0x10,0xfe,0xb6,0xd9,0xbd,0xf7,0x49,0x89,
  0xa2,0x4c,0xf4,0x96,0xd3,0xe0,0x21,0x6,0xd1,0xec,0x44,0x24,0xa0,0x1e,0x76,0xf,
  0xd9,0x4d,0x14,0xc4,0x11,0xbc,0xe5,0x90,0xc1,0x8d,0xa0,0x10,0xd8,0x39,0x18,0xf4,
  0x64,0xd6,0x43,0x30,0x37,0x37,0xb7,0xdc,0x32,0x21,0x21,0x5e,0xb2,0xa4,0x73,0x12,
  0xb2,0x18,0x77,0x25,0x7b,0x50,0xc1,0xcc,0xe0,0x41,0xf1,0x60,0x46,0xf4,0xe2,0xbc,
  0xa9,0xaf,0x3c,0x74,0xbf,0xd7,0xaf,0xa7,0xdf,0x4c,0xf7,0xca,0x5a,0xd0,0xf4,0xcf,
  0x7b,0x54,0x7d,0xf5,0xd5,0x57,0xd5,0x6f,0x4e,0x55,0x51,0x65,0xa7,0x2e,0xdf,0x8f,
  0x55,0xa4,0x4d,0x4a,0x4b,0x29,0x31,0x85,0x8b,0xa4,0x40,0x29,0x20,0x5,0x2a,0x32,
  0x24,0x65,0x57,0xc9,0x3e,0x29,0x9b,0x5b,0x9f,0xac,0x24,0x95,0x4e,0x33,0x9b,0xab,
  0x2,0xb0,0x72,0x79,0xbb,0x49,0xca,0x5d,0x52,0x62,0x95,0x2c,0x20,0x5,0x14,0xe6,
  0x0,0xb2,0xbb,0xf7,0x6d,0x33,0xf9,0xec,0xed,0xf7,0xea,0x0,0x88,0xaa,0x36,0x50,
  0xe5,0x2b,0x25,0xe3,0xd3,0x2f,0x3e,0x83,0xde,0x7,0xc7,0xf1,0xea,0x91,0x27,0xa1,
  0x24,0x54,0xb3,0x8b,0x4,0xc9,0xec,0x9b,0xa4,0x77,0xb2,0x7d,0xfc,0xfc,0xd5,0xf5,
  0x3,0x1,0xa0,0x64,0x53,0x49,0x9c,0x39,0xf6,0x2c,0x0,0xa0,0xf3,0xc6,0x11,0x17,
  0x90,0xcc,0x41,0xb8,0x2b,0x7f,0xef,0x1c,0x14,0x0,0xa8,0x12,0x5b,0xf,0x7f,0x3,
  0x0,0xf4,0xb6,0x7,0x59,0xf6,0x12,0xa,0xea,0xde,0x49,0xc6,0x75,0x0,0xcc,0xd7,
  0x2,0x40,0x62,0xe3,0xf6,0x1e,0x3e,0xbf,0xf5,0x3d,0x94,0xe1,0xc0,0x54,0x17,0xd8,
  0xad,0xd5,0xb1,0x6a,0x6,0x94,0xa0,0x9f,0x6d,0x28,0x70,0x61,0x4d,0xdc,0x7a,0x1d,
  0xab,0x64,0xe0,0xc6,0x5a,0x6b,0x6e,0xd6,0xfa,0x89,0x8f,0xaf,0xa9,0x2f,0x48,0xff,
  0xda,0x17,0x80,0xd5,0x2f,0xbf,0x5d,0x26,0x65,0x5d,0x29,0xcd,0x52,0x8b,0x89,0x64,
  0xa2,0xb3,0xcf,0xf9,0x5a,0x99,0xd,0x75,0xe2,0x4,0x0,0xfd,0xf5,0x7d,0x5,0xd,
  0x40,0x3,0x15,0x33,0x4,0xcd,0x17,0xd1,0x73,0xbd,0xae,0x8d,0x1b,0x1,0xc0,0xea,
  0x95,0x7,0x6d,0x55,0x5e,0xb7,0x8a,0x2f,0xb5,0xd8,0x44,0x6d,0x67,0x28,0xdf,0x89,
  0xd3,0x99,0xd,0x9e,0xde,0x63,0xd0,0xac,0xf3,0xc7,0x93,0xe7,0x1c,0x80,0xd3,0x57,
  0xbe,0x8b,0x95,0xbc,0x54,0xaa,0x2d,0xa7,0xd7,0x36,0xdf,0xab,0xc1,0x76,0x4,0xb4,
  0x0,0x40,0x69,0x0,0x31,0x3e,0x98,0x9c,0x1,0x55,0xbe,0xab,0xca,0x38,0x9c,0xcd,
  0xd4,0x16,0xcb,0x28,0xf,0x88,0x73,0x62,0xb2,0x66,0x99,0x97,0x98,0x90,0x87,0xc7,
  0x16,0x53,0x0,0x19,0xed,0x2c,0x50,0x1e,0xc8,0x76,0xb2,0xc,0x53,0x98,0xf1,0x2c,
  0xe1,0x60,0x65,0x9,0x5e,0xf6,0xca,0x31,0xe0,0x2e,0xd3,0x2,0x80,0x88,0x2a,0xcd,
  0x59,0x3,0xa5,0x54,0x86,0xd2,0x9a,0x3a,0x1,0x7a,0x36,0x4,0xd0,0x1,0x4d,0xc7,
  0x6,0x4c,0x83,0x17,0x98,0x68,0xe6,0xc,0x4c,0xa1,0xbd,0x24,0xc0,0x40,0x89,0x6c,
  0x19,0x90,0x53,0xdf,0x3,0xd0,0xfa,0xe6,0xc3,0x3b,0x6d,0x70,0xdc,0x82,0x38,0xda,
  0x8b,0x65,0x10,0x13,0x3,0xc0,0x7c,0xb0,0xb6,0xe5,0x6c,0xbb,0x4a,0x6e,0xde,0xfd,
  0xf4,0xad,0x41,0x55,0x5f,0x73,0xb0,0xba,0xc,0x9a,0xd,0xd0,0xcc,0xa,0xe,0xd0,
  0x34,0x52,0x0,0xb3,0x44,0x97,0x3e,0x37,0xb7,0xd6,0xb6,0xf,0x3,0xe8,0xe1,0xf1,
  0x83,0x66,0xa6,0x2c,0x5f,0x50,0x5e,0x8d,0x83,0x82,0x9b,0xf6,0xde,0xb7,0x25,0x48,
  0xc2,0xa3,0x56,0xa1,0x64,0xf7,0xce,0xda,0xfd,0xc3,0x0,0xae,0x3,0xd8,0x5f,0x70,
  0xd7,0x76,0xe3,0x29,0xfb,0xc7,0xb0,0x0,0x76,0x42,0x82,0xcb,0x40,0xf5,0x0,0x5c,
  0xf2,0x7a,0xaa,0x66,0xe6,0xbe,0xda,0x47,0xde,0x7a,0x41,0x90,0x89,0x9d,0x3,0x3b,
  0x56,0xc9,0x93,0x25,0xd8,0xba,0xb8,0xb2,0xb,0xa0,0x11,0xc,0x5e,0xa2,0xd5,0x73,
  0xee,0xb2,0x1f,0x15,0xc1,0x14,0x35,0xb1,0x69,0x19,0xe8,0xa9,0xca,0x30,0x74,0xc8,
  0x28,0x66,0x3e,0xd1,0x4a,0xce,0x99,0xeb,0xeb,0xc0,0xc4,0xb,0xed,0x37,0x0,0x4d,
  0xb2,0xf0,0xca,0xe3,0x1,0x0,0x44,0xb7,0x3e,0x3a,0xf9,0xa7,0x92,0x9d,0xd0,0xf0,
  0x49,0x83,0x6b,0x16,0x3c,0xcd,0xc8,0x66,0xab,0x5e,0xe0,0xff,0x20,0xc0,0xae,0xcd,
  0x2d,0x2,0x80,0xaf,0x2f,0xbc,0x79,0x55,0xa9,0xcb,0x4a,0x26,0xaa,0xec,0x17,0xa6,
  0x5a,0x88,0x66,0x99,0xe2,0x7c,0xb6,0x20,0xfb,0xe0,0x38,0x1,0x4d,0x6b,0x61,0xf1,
  0xef,0x7b,0x16,0x40,0xe5,0xa9,0x58,0x7f,0x3f,0xab,0x1,0x67,0x0,0xd,0xa2,0xe7,
  0x6f,0xce,0x3c,0x2b,0xd4,0xb1,0xca,0x3,0xc9,0x2c,0x5a,0xe5,0x87,0xd7,0xd4,0x95,
  0x45,0x26,0x99,0x32,0xc9,0xfc,0xd1,0x47,0x27,0xaa,0xdc,0x57,0x1e,0xc9,0xca,0x13,
  0xcc,0x6f,0x25,0x3f,0x78,0xe1,0x47,0x93,0xee,0xaf,0x61,0xb5,0x0,0x4,0xd5,0xce,
  0x51,0x1,0x4c,0xf4,0xd4,0x1a,0xe6,0x5f,0xd8,0x43,0x74,0xe8,0x6c,0xce,0xc4,0x41,
  0x0,0x50,0x8e,0xfb,0xf0,0x7a,0x7b,0x82,0x66,0xa7,0x89,0xe8,0x89,0x77,0x52,0x87,
  0x4f,0x9f,0xb3,0xac,0xc,0xf,0x4,0x0,0x68,0xba,0x75,0x5a,0x4b,0x7e,0x3e,0xf,
  0xfd,0xe7,0x17,0xc8,0xa3,0xb,0xf6,0xdb,0x46,0x1d,0x0,0x95,0x5d,0x0,0x0,0xfc,
  0xe9,0xf5,0x25,0x4d,0xff,0x70,0x8d,0xc0,0x5f,0xcd,0x1b,0x3a,0xa3,0xb4,0xdd,0xc4,
  0xb4,0x17,0x16,0xff,0xba,0x57,0xe9,0xb8,0x2e,0x0,0x6b,0xb2,0xf7,0xd2,0x12,0x68,
  0x5a,0x4a,0xd3,0x84,0x98,0x6,0x38,0x6e,0x80,0x66,0x47,0x69,0x86,0xe0,0x28,0x1,
  0x4d,0x6f,0xe1,0xe5,0x3f,0x76,0x6b,0x3b,0xdc,0x2f,0x80,0xff,0xc3,0xfe,0x5,0xc3,
  0xe2,0x83,0x2a,0x21,0xdc,0x2d,0xd0,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,
  0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // python
  0x0,0x6,
  0x7,0x80,0xaf,0x5e,
  0x0,0x70,
  0x0,0x79,0x0,0x74,0x0,0x68,0x0,0x6f,0x0,0x6e,
    // python.png
  0x0,0xa,
  0xf,0x6e,0x56,0x7,
  0x0,0x70,
  0x0,0x79,0x0,0x74,0x0,0x68,0x0,0x6f,0x0,0x6e,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/python
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/python/python.png
  0x0,0x0,0x0,0x12,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_pythontool)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_pythontool))

int QT_MANGLE_NAMESPACE(qCleanupResources_pythontool)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_pythontool))

==> avogadro-debuginfo-1.2.0-2.tar.xz: usr/src/debug/avogadro-1.2.0-2/libavogadro/src/qrc_pythontool.cxx <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/avogadro/avogadro-1.2.0-2.i686/src/avogadro-1.2.0/libavogadro/src/python.png
  0x0,0x0,0x4,0x54,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x20,0x0,0x0,0x0,0x20,0x8,0x6,0x0,0x0,0x0,0x73,0x7a,0x7a,0xf4,
  0x0,0x0,0x0,0x4,0x73,0x42,0x49,0x54,0x8,0x8,0x8,0x8,0x7c,0x8,0x64,0x88,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xa,0xf0,0x0,0x0,0xa,0xf0,
  0x1,0x42,0xac,0x34,0x98,0x0,0x0,0x0,0x25,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,
  0x74,0x77,0x61,0x72,0x65,0x0,0x4d,0x61,0x63,0x72,0x6f,0x6d,0x65,0x64,0x69,0x61,
  0x20,0x46,0x69,0x72,0x65,0x77,0x6f,0x72,0x6b,0x73,0x20,0x4d,0x58,0x20,0x32,0x30,
  0x30,0x34,0x87,0x76,0xac,0xcf,0x0,0x0,0x0,0x16,0x74,0x45,0x58,0x74,0x43,0x72,
  0x65,0x61,0x74,0x69,0x6f,0x6e,0x20,0x54,0x69,0x6d,0x65,0x0,0x30,0x36,0x2f,0x30,
  0x35,0x2f,0x30,0x34,0x4d,0xbe,0xe6,0x71,0x0,0x0,0x3,0xa3,0x49,0x44,0x41,0x54,
  0x78,0x9c,0xb5,0x56,0x4d,0x88,0x1c,0x55,0x10,0xfe,0xb6,0xd9,0xbd,0xf7,0x49,0x89,
  0xa2,0x4c,0xf4,0x96,0xd3,0xe0,0x21,0x6,0xd1,0xec,0x44,0x24,0xa0,0x1e,0x76,0xf,
  0xd9,0x4d,0x14,0xc4,0x11,0xbc,0xe5,0x90,0xc1,0x8d,0xa0,0x10,0xd8,0x39,0x18,0xf4,
  0x64,0xd6,0x43,0x30,0x37,0x37,0xb7,0xdc,0x32,0x21,0x21,0x5e,0xb2,0xa4,0x73,0x12,
  0xb2,0x18,0x77,0x25,0x7b,0x50,0xc1,0xcc,0xe0,0x41,0xf1,0x60,0x46,0xf4,0xe2,0xbc,
  0xa9,0xaf,0x3c,0x74,0xbf,0xd7,0xaf,0xa7,0xdf,0x4c,0xf7,0xca,0x5a,0xd0,0xf4,0xcf,
  0x7b,0x54,0x7d,0xf5,0xd5,0x57,0xd5,0x6f,0x4e,0x55,0x51,0x65,0xa7,0x2e,0xdf,0x8f,
  0x55,0xa4,0x4d,0x4a,0x4b,0x29,0x31,0x85,0x8b,0xa4,0x40,0x29,0x20,0x5,0x2a,0x32,
  0x24,0x65,0x57,0xc9,0x3e,0x29,0x9b,0x5b,0x9f,0xac,0x24,0x95,0x4e,0x33,0x9b,0xab,
  0x2,0xb0,0x72,0x79,0xbb,0x49,0xca,0x5d,0x52,0x62,0x95,0x2c,0x20,0x5,0x14,0xe6,
  0x0,0xb2,0xbb,0xf7,0x6d,0x33,0xf9,0xec,0xed,0xf7,0xea,0x0,0x88,0xaa,0x36,0x50,
  0xe5,0x2b,0x25,0xe3,0xd3,0x2f,0x3e,0x83,0xde,0x7,0xc7,0xf1,0xea,0x91,0x27,0xa1,
  0x24,0x54,0xb3,0x8b,0x4,0xc9,0xec,0x9b,0xa4,0x77,0xb2,0x7d,0xfc,0xfc,0xd5,0xf5,
  0x3,0x1,0xa0,0x64,0x53,0x49,0x9c,0x39,0xf6,0x2c,0x0,0xa0,0xf3,0xc6,0x11,0x17,
  0x90,0xcc,0x41,0xb8,0x2b,0x7f,0xef,0x1c,0x14,0x0,0xa8,0x12,0x5b,0xf,0x7f,0x3,
  0x0,0xf4,0xb6,0x7,0x59,0xf6,0x12,0xa,0xea,0xde,0x49,0xc6,0x75,0x0,0xcc,0xd7,
  0x2,0x40,0x62,0xe3,0xf6,0x1e,0x3e,0xbf,0xf5,0x3d,0x94,0xe1,0xc0,0x54,0x17,0xd8,
  0xad,0xd5,0xb1,0x6a,0x6,0x94,0xa0,0x9f,0x6d,0x28,0x70,0x61,0x4d,0xdc,0x7a,0x1d,
  0xab,0x64,0xe0,0xc6,0x5a,0x6b,0x6e,0xd6,0xfa,0x89,0x8f,0xaf,0xa9,0x2f,0x48,0xff,
  0xda,0x17,0x80,0xd5,0x2f,0xbf,0x5d,0x26,0x65,0x5d,0x29,0xcd,0x52,0x8b,0x89,0x64,
  0xa2,0xb3,0xcf,0xf9,0x5a,0x99,0xd,0x75,0xe2,0x4,0x0,0xfd,0xf5,0x7d,0x5,0xd,
  0x40,0x3,0x15,0x33,0x4,0xcd,0x17,0xd1,0x73,0xbd,0xae,0x8d,0x1b,0x1,0xc0,0xea,
  0x95,0x7,0x6d,0x55,0x5e,0xb7,0x8a,0x2f,0xb5,0xd8,0x44,0x6d,0x67,0x28,0xdf,0x89,
  0xd3,0x99,0xd,0x9e,0xde,0x63,0xd0,0xac,0xf3,0xc7,0x93,0xe7,0x1c,0x80,0xd3,0x57,
  0xbe,0x8b,0x95,0xbc,0x54,0xaa,0x2d,0xa7,0xd7,0x36,0xdf,0xab,0xc1,0x76,0x4,0xb4,
  0x0,0x40,0x69,0x0,0x31,0x3e,0x98,0x9c,0x1,0x55,0xbe,0xab,0xca,0x38,0x9c,0xcd,
  0xd4,0x16,0xcb,0x28,0xf,0x88,0x73,0x62,0xb2,0x66,0x99,0x97,0x98,0x90,0x87,0xc7,
  0x16,0x53,0x0,0x19,0xed,0x2c,0x50,0x1e,0xc8,0x76,0xb2,0xc,0x53,0x98,0xf1,0x2c,
  0xe1,0x60,0x65,0x9,0x5e,0xf6,0xca,0x31,0xe0,0x2e,0xd3,0x2,0x80,0x88,0x2a,0xcd,
  0x59,0x3,0xa5,0x54,0x86,0xd2,0x9a,0x3a,0x1,0x7a,0x36,0x4,0xd0,0x1,0x4d,0xc7,
  0x6,0x4c,0x83,0x17,0x98,0x68,0xe6,0xc,0x4c,0xa1,0xbd,0x24,0xc0,0x40,0x89,0x6c,
  0x19,0x90,0x53,0xdf,0x3,0xd0,0xfa,0xe6,0xc3,0x3b,0x6d,0x70,0xdc,0x82,0x38,0xda,
  0x8b,0x65,0x10,0x13,0x3,0xc0,0x7c,0xb0,0xb6,0xe5,0x6c,0xbb,0x4a,0x6e,0xde,0xfd,
  0xf4,0xad,0x41,0x55,0x5f,0x73,0xb0,0xba,0xc,0x9a,0xd,0xd0,0xcc,0xa,0xe,0xd0,
  0x34,0x52,0x0,0xb3,0x44,0x97,0x3e,0x37,0xb7,0xd6,0xb6,0xf,0x3,0xe8,0xe1,0xf1,
  0x83,0x66,0xa6,0x2c,0x5f,0x50,0x5e,0x8d,0x83,0x82,0x9b,0xf6,0xde,0xb7,0x25,0x48,
  0xc2,0xa3,0x56,0xa1,0x64,0xf7,0xce,0xda,0xfd,0xc3,0x0,0xae,0x3,0xd8,0x5f,0x70,
  0xd7,0x76,0xe3,0x29,0xfb,0xc7,0xb0,0x0,0x76,0x42,0x82,0xcb,0x40,0xf5,0x0,0x5c,
  0xf2,0x7a,0xaa,0x66,0xe6,0xbe,0xda,0x47,0xde,0x7a,0x41,0x90,0x89,0x9d,0x3,0x3b,
  0x56,0xc9,0x93,0x25,0xd8,0xba,0xb8,0xb2,0xb,0xa0,0x11,0xc,0x5e,0xa2,0xd5,0x73,
  0xee,0xb2,0x1f,0x15,0xc1,0x14,0x35,0xb1,0x69,0x19,0xe8,0xa9,0xca,0x30,0x74,0xc8,
  0x28,0x66,0x3e,0xd1,0x4a,0xce,0x99,0xeb,0xeb,0xc0,0xc4,0xb,0xed,0x37,0x0,0x4d,
  0xb2,0xf0,0xca,0xe3,0x1,0x0,0x44,0xb7,0x3e,0x3a,0xf9,0xa7,0x92,0x9d,0xd0,0xf0,
  0x49,0x83,0x6b,0x16,0x3c,0xcd,0xc8,0x66,0xab,0x5e,0xe0,0xff,0x20,0xc0,0xae,0xcd,
  0x2d,0x2,0x80,0xaf,0x2f,0xbc,0x79,0x55,0xa9,0xcb,0x4a,0x26,0xaa,0xec,0x17,0xa6,
  0x5a,0x88,0x66,0x99,0xe2,0x7c,0xb6,0x20,0xfb,0xe0,0x38,0x1,0x4d,0x6b,0x61,0xf1,
  0xef,0x7b,0x16,0x40,0xe5,0xa9,0x58,0x7f,0x3f,0xab,0x1,0x67,0x0,0xd,0xa2,0xe7,
  0x6f,0xce,0x3c,0x2b,0xd4,0xb1,0xca,0x3,0xc9,0x2c,0x5a,0xe5,0x87,0xd7,0xd4,0x95,
  0x45,0x26,0x99,0x32,0xc9,0xfc,0xd1,0x47,0x27,0xaa,0xdc,0x57,0x1e,0xc9,0xca,0x13,
  0xcc,0x6f,0x25,0x3f,0x78,0xe1,0x47,0x93,0xee,0xaf,0x61,0xb5,0x0,0x4,0xd5,0xce,
  0x51,0x1,0x4c,0xf4,0xd4,0x1a,0xe6,0x5f,0xd8,0x43,0x74,0xe8,0x6c,0xce,0xc4,0x41,
  0x0,0x50,0x8e,0xfb,0xf0,0x7a,0x7b,0x82,0x66,0xa7,0x89,0xe8,0x89,0x77,0x52,0x87,
  0x4f,0x9f,0xb3,0xac,0xc,0xf,0x4,0x0,0x68,0xba,0x75,0x5a,0x4b,0x7e,0x3e,0xf,
  0xfd,0xe7,0x17,0xc8,0xa3,0xb,0xf6,0xdb,0x46,0x1d,0x0,0x95,0x5d,0x0,0x0,0xfc,
  0xe9,0xf5,0x25,0x4d,0xff,0x70,0x8d,0xc0,0x5f,0xcd,0x1b,0x3a,0xa3,0xb4,0xdd,0xc4,
  0xb4,0x17,0x16,0xff,0xba,0x57,0xe9,0xb8,0x2e,0x0,0x6b,0xb2,0xf7,0xd2,0x12,0x68,
  0x5a,0x4a,0xd3,0x84,0x98,0x6,0x38,0x6e,0x80,0x66,0x47,0x69,0x86,0xe0,0x28,0x1,
  0x4d,0x6f,0xe1,0xe5,0x3f,0x76,0x6b,0x3b,0xdc,0x2f,0x80,0xff,0xc3,0xfe,0x5,0xc3,
  0xe2,0x83,0x2a,0x21,0xdc,0x2d,0xd0,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,
  0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // python
  0x0,0x6,
  0x7,0x80,0xaf,0x5e,
  0x0,0x70,
  0x0,0x79,0x0,0x74,0x0,0x68,0x0,0x6f,0x0,0x6e,
    // python.png
  0x0,0xa,
  0xf,0x6e,0x56,0x7,
  0x0,0x70,
  0x0,0x79,0x0,0x74,0x0,0x68,0x0,0x6f,0x0,0x6e,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/python
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/python/python.png
  0x0,0x0,0x0,0x12,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_pythontool)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_pythontool))

int QT_MANGLE_NAMESPACE(qCleanupResources_pythontool)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_pythontool))
